import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import Ads from "@/components/sections/home/ads";
import ContentCards from "@/components/sections/request-a-field-visit/content-cards";
import ImagesCards from "@/components/sections/request-a-field-visit/images-cards";
import RequestFieldVisitForm from "@/components/sections/request-a-field-visit/request-field-visit-form";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import BlurFade from "@/components/ui/blur-fade";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { LocaleParams } from "@/types/params";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";

async function Page({ params }: { params: LocaleParams }) {
	const { locale } = await params;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/request-a-field-visit",
			label: {
				en: "Request a field visit",
				ar: "طلب زيارة ميدانية",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
	]);


	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<LocomotiveScrollWrapper>
				<main className="block overflow-hidden text-gray-700">
					<Header />
					<PageBreadcrump
						backgroundUrl={"/heros/reguest-field-visit.png"}
						locale={locale}
						subtitle={{
							en: "Bin Taleb Company",
							ar: "شركة بن طالب",
						}}
						title={{
							en: "Request a field visit",
							ar: "طلب زيارة ميدانية",
						}}
						breadcrumbItems={breadcrumbItems}
					/>
					<div className="">
						<div className="mx-auto my-4 w-full max-w-10xl p-5 md:p-14">
							<div className="flex flex-col gap-8 md:flex-row">
								<div className="flex-[50%]">
									<RequestFieldVisitForm locale={locale} />
								</div>
								<div className="flex-[50%]">
									<BlurFade
										duration={1.5}
										inView
										direction={"right"}
										offset={40}
										className="relative mt-3 flex flex-col items-center gap-8"
									>
										<ImagesCards />
										<ContentCards />
									</BlurFade>
								</div>
							</div>
						</div>
						<Ads />
						<Footer />
					</div>
				</main>
			</LocomotiveScrollWrapper>
		</HydrationBoundary>
	);
}

export default Page;
